DependencyGraph

Struct DependencyGraph 

pub struct DependencyGraph { /* private fields */ }
Represents a graph of package dependencies to be resolved and installed.

This structure helps determine which packages need to be installed, including any dependencies they require.

Implementations

Source

impl DependencyGraph

pub fn new(install_packages: Vec<String>) -> Self

Creates a new DependencyGraph with the specified packages to install.

Parameters
  • install_packages - List of package names to install
Returns

A new DependencyGraph instance

pub fn resolve(&self, manifest: &PackageManifest) -> HashMap<String, String>

Resolves all dependencies for the requested packages.

This method:

  1. Starts with the user-requested packages
  2. For each package, adds its dependencies to the list to process
  3. Continues until all dependencies are resolved
Parameters
  • manifest - A PackageManifest of all available packages
Returns

A HashMap where keys are filenames and values are download URLs for all required packages

pub fn resolve_interned( &self, manifest: &InternedPackageManifest, ) -> HashMap<String, String>

Resolves all dependencies for the requested packages using an interned manifest.

This method:

  1. Starts with the user-requested packages
  2. For each package, adds its dependencies to the list to process
  3. Continues until all dependencies are resolved
Parameters
  • manifest - An InternedPackageManifest of all available packages
Returns

A HashMap where keys are filenames and values are download URLs for all required packages