SerializableInternedManifest

Struct SerializableInternedManifest 

pub struct SerializableInternedManifest {
Show 15 fields pub string_table: Vec<String>, pub names: Vec<Option<u32>>, pub full_names: Vec<Option<u32>>, pub owners: Vec<Option<u32>>, pub package_urls: Vec<Option<u32>>, pub dates_created: Vec<OffsetDateTime>, pub dates_updated: Vec<OffsetDateTime>, pub uuid4s: Vec<Option<u32>>, pub rating_scores: Vec<Option<u32>>, pub is_pinned: Vec<Option<bool>>, pub is_deprecated: Vec<Option<bool>>, pub has_nsfw_content: Vec<Option<bool>>, pub categories: Vec<Vec<u32>>, pub version_ranges: Vec<(usize, usize)>, pub versions: SerializableInternedVersionManifest,
}
Serializable representation of an interned package manifest.

This structure converts the runtime InternedPackageManifest into a format that can be efficiently serialized and deserialized. The string interner is converted to a simple vector of strings (the string table), and all interned keys become u32 indices into this table.

This separation allows for optimal serialization performance while maintaining the memory efficiency benefits of string interning at runtime.

Fields

string_table: Vec<String>names: Vec<Option<u32>>full_names: Vec<Option<u32>>owners: Vec<Option<u32>>package_urls: Vec<Option<u32>>dates_created: Vec<OffsetDateTime>dates_updated: Vec<OffsetDateTime>uuid4s: Vec<Option<u32>>rating_scores: Vec<Option<u32>>is_pinned: Vec<Option<bool>>is_deprecated: Vec<Option<bool>>has_nsfw_content: Vec<Option<bool>>categories: Vec<Vec<u32>>version_ranges: Vec<(usize, usize)>versions: SerializableInternedVersionManifest