SerializableInternedVersionManifest

Struct SerializableInternedVersionManifest 

pub struct SerializableInternedVersionManifest {
    pub package_indices: Vec<usize>,
    pub version_numbers: Vec<Option<u32>>,
    pub download_urls: Vec<Option<u32>>,
    pub dependencies: Vec<Vec<u32>>,
    pub dates_created: Vec<OffsetDateTime>,
    pub descriptions: Vec<Option<u32>>,
    pub icons: Vec<Option<u32>>,
    pub downloads: Vec<Option<u32>>,
    pub website_urls: Vec<Option<u32>>,
    pub is_active: Vec<Option<bool>>,
    pub uuid4s: Vec<Option<u32>>,
    pub file_sizes: Vec<Option<u64>>,
}
Serializable representation of interned version data.

Contains version information with string values represented as u32 indices into the parent manifest’s string table. This allows efficient serialization while maintaining the benefits of string interning.

Fields

package_indices: Vec<usize>version_numbers: Vec<Option<u32>>download_urls: Vec<Option<u32>>dependencies: Vec<Vec<u32>>dates_created: Vec<OffsetDateTime>descriptions: Vec<Option<u32>>icons: Vec<Option<u32>>downloads: Vec<Option<u32>>website_urls: Vec<Option<u32>>is_active: Vec<Option<bool>>uuid4s: Vec<Option<u32>>file_sizes: Vec<Option<u64>>