pub type StringInterner = Rodeo;Expand description
Type alias for the string interner (lasso::Rodeo).
The interner stores unique strings and returns small integer keys that can be used to retrieve them later, reducing memory usage for repeated strings.
Aliased Type
pub struct StringInterner { /* private fields */ }