pub struct DependencyGraph { /* private fields */ }Expand description
Represents a graph of package dependencies to be resolved and installed.
This structure helps determine which packages need to be installed, including any dependencies they require.
Implementations
Sourceimpl DependencyGraph
impl DependencyGraph
Sourcepub fn resolve(&self, manifest: &PackageManifest) -> HashMap<String, String>
pub fn resolve(&self, manifest: &PackageManifest) -> HashMap<String, String>
Resolves all dependencies for the requested packages.
This method:
- Starts with the user-requested packages
- For each package, adds its dependencies to the list to process
- Continues until all dependencies are resolved
Parameters
manifest- A PackageManifest of all available packages
Returns
A HashMap where keys are filenames and values are download URLs for all required packages
Sourcepub fn resolve_interned(
&self,
manifest: &InternedPackageManifest,
) -> HashMap<String, String>
pub fn resolve_interned( &self, manifest: &InternedPackageManifest, ) -> HashMap<String, String>
Resolves all dependencies for the requested packages using an interned manifest.
This method:
- Starts with the user-requested packages
- For each package, adds its dependencies to the list to process
- Continues until all dependencies are resolved
Parameters
manifest- An InternedPackageManifest of all available packages
Returns
A HashMap where keys are filenames and values are download URLs for all required packages